@@ -3,11 +3,11 @@
 #'   Id string for object. Used to display object.
 #' @param type (`character(1)`)\cr
 #'   Learner type.
-#' @param next.learner ([Learner`)\cr
+#' @param next.learner ([Learner])\cr
 #'   Learner to wrap.
 #' @param package ([character])\cr
 #'   Packages to load when loading learner.
-#' @param par.set ([ParamSet`)\cr
+#' @param par.set ([ParamSet])\cr
 #'   Parameter set.
 #' @param par.vals ([list])\cr
 #'   Optional list of named (hyper)parameter values.
@@ -18,7 +18,7 @@
 #' @keywords internal
 #' @export
 makeBaseWrapper = function(id, type, next.learner, package = character(0L), par.set = makeParamSet(),
-  par.vals = list(), learner.subclass, model.subclass) {
+  par.vals = list(), learner.subclass, model.subclass, cache = FALSE) {
   if (inherits(next.learner, "OptWrapper") && is.element("TuneWrapper", learner.subclass))
     stop("Cannot wrap a tuning wrapper around another optimization wrapper!")
   ns = intersect(names(par.set$pars), names(next.learner$par.set$pars))
@@ -32,7 +32,8 @@ makeBaseWrapper = function(id, type, next.learner, package = character(0L), par.
     package = union(package, next.learner$package),
     properties = NULL, # these are handled by the getter anyway
     par.set = par.set,
-    par.vals = par.vals
+    par.vals = par.vals,
+    cache = cache
   )
   learner$fix.factors.prediction = FALSE
   learner$next.learner = next.learner
