@@ -1,12 +1,17 @@
+#' @title Create a classification task.
+#' @inheritParams Task
+#' @seealso [Task] [CostSensTask] [ClusterTask] [MultilabelTask] [RegrTask] [SurvTask]
+#' @rdname ClassifTask
+#' @aliases ClassifTask
 #' @export
-#' @rdname Task
-makeClassifTask = function(id = deparse(substitute(data)), data, target, weights = NULL, blocking = NULL, positive = NA_character_, fixup.data = "warn", check.data = TRUE) {
+makeClassifTask = function(id = deparse(substitute(data)), data, target, weights = NULL, blocking = NULL, coordinates = NULL, positive = NA_character_, fixup.data = "warn", check.data = TRUE) {
   assertString(id)
   assertDataFrame(data)
   assertString(target)
   # some code on cran passed stuff like positive=1, we can live with the convert here
   if (isScalarNumeric(positive))
     positive = as.character(positive)
+
   assertString(positive, na.ok = TRUE)
   assertChoice(fixup.data, choices = c("no", "quiet", "warn"))
   assertFlag(check.data)
@@ -20,17 +25,19 @@ makeClassifTask = function(id = deparse(substitute(data)), data, target, weights
       data[[target]] = droplevels(x)
     }
   }
-  task = makeSupervisedTask("classif", data, target, weights, blocking, fixup.data = fixup.data, check.data = check.data)
+  task = makeSupervisedTask("classif", data, target, weights, blocking, coordinates, fixup.data = fixup.data, check.data = check.data)
 
   if (check.data) {
     assertFactor(data[[target]], any.missing = FALSE, empty.levels.ok = FALSE, .var.name = target)
   }
 
-  task$task.desc = makeClassifTaskDesc(id, data, target, weights, blocking, positive)
+  task$task.desc = makeClassifTaskDesc(id, data, target, weights, blocking, positive, coordinates)
   addClasses(task, "ClassifTask")
 }
 
-makeClassifTaskDesc = function(id, data, target, weights, blocking, positive) {
+#' @export
+#' @rdname makeTaskDesc
+makeClassifTaskDesc = function(id, data, target, weights, blocking, positive, coordinates) {
   levs = levels(data[[target]])
   m = length(levs)
   if (is.na(positive)) {
@@ -41,10 +48,11 @@ makeClassifTaskDesc = function(id, data, target, weights, blocking, positive) {
       stop("Cannot set a positive class for a multiclass problem!")
     assertChoice(positive, choices = levs)
   }
-  td = makeTaskDescInternal("classif", id, data, target, weights, blocking)
+  td = makeTaskDescInternal("classif", id, data, target, weights, blocking, coordinates)
   td$class.levels = levs
   td$positive = positive
   td$negative = NA_character_
+  td$class.distribution = table(data[target])
   if (length(td$class.levels) == 1L)
     td$negative = stri_paste("not_", positive)
   else if (length(td$class.levels) == 2L)
@@ -54,11 +62,11 @@ makeClassifTaskDesc = function(id, data, target, weights, blocking, positive) {
 
 #' @export
 print.ClassifTask = function(x, ...) {
-  # remove 1st newline
-  di = printToChar(table(getTaskTargets(x)), collapse = NULL)[-1L]
+  di = printToChar(x$task.desc$class.distribution)
   m = length(x$task.desc$class.levels)
   print.SupervisedTask(x)
-  catf("Classes: %i", m)
-  catf(collapse(di, "\n"))
-  catf("Positive class: %s", x$task.desc$positive)
+  catf("Classes: %i", m, newline = FALSE)
+  # remove 1st newline
+  cat(di)
+  catf("\nPositive class: %s", x$task.desc$positive)
 }
