@@ -2,7 +2,7 @@
 #' @rdname FeatSelControl
 makeFeatSelControlRandom = function(same.resampling.instance = TRUE,
   maxit = 100L, max.features = NA_integer_, prob = 0.5, tune.threshold = FALSE,
-  tune.threshold.args = list(), log.fun = NULL) {
+  tune.threshold.args = list(), log.fun = "default") {
 
   maxit = asCount(maxit, positive = TRUE)
   makeFeatSelControl(same.resampling.instance = same.resampling.instance,
