@@ -32,26 +32,27 @@ makeRLearner.classif.RRF = function() {
     properties = c("twoclass", "multiclass", "prob", "numerics", "factors", "featimp"),
     name = "Regularized Random Forests",
     short.name = "RRF",
-    note = ""
+    note = "",
+    callees = "RRF"
   )
 }
 
 #' @export
 trainLearner.classif.RRF = function(.learner, .task, .subset, .weights, ...) {
   RRF::RRF(formula = getTaskFormula(.task), data = getTaskData(.task, .subset),
-           keep.forest= TRUE, ...)
+           keep.forest = TRUE, ...)
 }
 
 #' @export
 predictLearner.classif.RRF = function(.learner, .model, .newdata, ...) {
-  type = ifelse(.learner$predict.type=="response", "response", "prob")
+  type = ifelse(.learner$predict.type == "response", "response", "prob")
   p = predict(object = .model$learner.model, newdata = .newdata, type = type, ...)
   return(p)
 }
 
 #' @export
 getFeatureImportanceLearner.classif.RRF = function(.learner, .model, ...) {
-  mod = getLearnerModel(.model)
+  mod = getLearnerModel(.model, more.unwrap = TRUE)
   ctrl = list(...)
   if (is.null(ctrl$type)) {
     ctrl$type = 2L
@@ -61,5 +62,5 @@ getFeatureImportanceLearner.classif.RRF = function(.learner, .model, ...) {
       stop("You need to train the learner with parameter 'importance' set to TRUE")
   }
 
-  RRF::importance(mod, ctrl$type)[,1]
+  RRF::importance(mod, ctrl$type)[, 1]
 }
