@@ -21,10 +21,11 @@ makeRLearner.classif.h2o.glm = function() {
       makeUntypedLearnerParam("beta_constraints"),
       makeLogicalLearnerParam("intercept", default = TRUE)
     ),
-    properties = c("twoclass", "numerics", "factors", "prob", "weights"),
+    properties = c("twoclass", "numerics", "factors", "prob", "weights", "missings", "featimp"),
     name = "h2o.glm",
     short.name = "h2o.glm",
-    note = "'family' is always set to 'binomial' to get a binary classifier."
+    note = '`family` is always set to `"binomial"` to get a binary classifier. The default value of `missing_values_handling` is `"MeanImputation"`, so missing values are automatically mean-imputed.',
+    callees = "h2o.glm"
   )
 }
 
@@ -56,11 +57,9 @@ predictLearner.classif.h2o.glm = function(.learner, .model, .newdata, ...) {
 
   # check if class names are integers. if yes, colnames of p.df need to be adapted
   int = stri_detect_regex(p.df$predict, "^[[:digit:]]+$")
-  if (any(int)) {
-    pcol = stri_detect_regex("^p[[:digit:]]+$", colnames(p.df))
-    if (any(pcol))
-      colnames(p.df)[pcol] = stri_sub(colnames(p.df)[pcol], 2L)
-  }
+  pcol = stri_detect_regex(colnames(p.df), "^p[[:digit:]]+$")
+  if (any(int) && any(pcol))
+    colnames(p.df)[pcol] = stri_sub(colnames(p.df)[pcol], 2L)
 
   if (.learner$predict.type == "response") {
     return(p.df$predict)
@@ -70,3 +69,17 @@ predictLearner.classif.h2o.glm = function(.learner, .model, .newdata, ...) {
     return(ret)
   }
 }
+
+#' @export
+getFeatureImportanceLearner.classif.h2o.glm = function(.learner, .model, ...) {
+  mod = getLearnerModel(.model, more.unwrap = TRUE)
+  extractH2OGlmVarImp(mod, ...)
+}
+
+
+extractH2OGlmVarImp = function(.learner.model, ...) {
+  imp = na.omit(as.data.frame(h2o::h2o.varimp(.learner.model)))
+  res = imp$coefficients
+  names(res) = imp$names
+  res
+}
