@@ -16,7 +16,8 @@ makeRLearner.classif.kknn = function() {
     ),
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "k-Nearest Neighbor",
-    short.name = "kknn"
+    short.name = "kknn",
+    callees = "kknn"
   )
 }
 
