@@ -10,7 +10,8 @@ makeRLearner.classif.linDA = function() {
     properties = c("twoclass", "multiclass", "numerics"),
     name = "Linear Discriminant Analysis",
     short.name = "linda",
-    note = "Set `validation = NULL` by default to disable internal test set validation."
+    note = "Set `validation = NULL` by default to disable internal test set validation.",
+    callees = c("linDA", "classify")
   )
 }
 
