@@ -23,7 +23,8 @@ makeRLearner.classif.mda = function() {
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "Mixture Discriminant Analysis",
     short.name = "mda",
-    note = '`keep.fitted` has been set to `FALSE` by default for speed and we use `start.method = "lvq"` for more robust behavior / less technical crashes.'
+    note = '`keep.fitted` has been set to `FALSE` by default for speed and we use `start.method = "lvq"` for more robust behavior / less technical crashes.',
+    callees = c("mda", "mda.start")
   )
 }
 
@@ -35,6 +36,6 @@ trainLearner.classif.mda = function(.learner, .task, .subset, .weights = NULL,
 
 #' @export
 predictLearner.classif.mda = function(.learner, .model, .newdata, ...) {
-  type = ifelse(.learner$predict.type=="response", "class", "posterior")
+  type = ifelse(.learner$predict.type == "response", "class", "posterior")
   predict(.model$learner.model, newdata = .newdata, type = type, ...)
 }
