@@ -10,19 +10,19 @@ makeRLearner.classif.neuralnet = function() {
       makeIntegerLearnerParam(id = "rep", default = 1L, lower = 1L),
       makeNumericVectorLearnerParam(id = "startweights"),
       makeNumericVectorLearnerParam(id = "learningrate.limit"),
-      makeUntypedLearnerParam(id = "learningrate.factor", 
+      makeUntypedLearnerParam(id = "learningrate.factor",
                               default = list(minus = 0.5, plus = 1.2)),
       makeNumericLearnerParam(id = "learningrate"),
       makeDiscreteLearnerParam(id = "lifesign", default = "none",
-                               values = c("none","minimal","full")),
+                               values = c("none", "minimal", "full")),
       makeIntegerLearnerParam(id = "lifesign.step", default = 1000L),
       makeDiscreteLearnerParam(id = "algorithm", default = "rprop+",
-                               values=c("backprop","rprop+","rprop-","sag","slr")),
+                               values = c("backprop", "rprop+", "rprop-", "sag", "slr")),
       makeDiscreteLearnerParam(id = "err.fct", default = "ce",
-                               values=c("sse","ce")),
+                               values = c("sse", "ce")),
       # FIXME default in neuralnet() or err.fct is "sse"
       makeDiscreteLearnerParam(id = "act.fct", default = "logistic",
-                               values=c("logistic","tanh")),
+                               values = c("logistic", "tanh")),
       makeNumericVectorLearnerParam(id = "exclude"),
       makeNumericVectorLearnerParam(id = "constant.weights"),
       makeLogicalLearnerParam(id = "likelihood", default = FALSE)
@@ -31,7 +31,8 @@ makeRLearner.classif.neuralnet = function() {
     properties = c("twoclass", "numerics", "prob"),
     name = "Neural Network from neuralnet",
     short.name = "neuralnet",
-    note = "`err.fct` has been set to `ce` and `linear.output` to FALSE to do classification."
+    note = "`err.fct` has been set to `ce` and `linear.output` to FALSE to do classification.",
+    callees = "neuralnet"
   )
 }
 
@@ -41,45 +42,45 @@ trainLearner.classif.neuralnet = function(.learner, .task, .subset, .weights = N
   cf = as.character(f)
   taskdat = getTaskData(.task, .subset)
   nms = names(taskdat)
-  formula_head = as.character(f)[2]
-  if (is.character(taskdat[[formula_head]])){
-    taskdat[[formula_head]] = as.factor(taskdat[[formula_head]])
-    taskdat[[formula_head]] = as.numeric(taskdat[[formula_head]])
+  formula.head = as.character(f)[2]
+  if (is.character(taskdat[[formula.head]])){
+    taskdat[[formula.head]] = as.factor(taskdat[[formula.head]])
+    taskdat[[formula.head]] = as.numeric(taskdat[[formula.head]])
   }
-  if (is.factor(taskdat[[formula_head]])){
-    taskdat[[formula_head]] = as.numeric(taskdat[[formula_head]])
+  if (is.factor(taskdat[[formula.head]])){
+    taskdat[[formula.head]] = as.numeric(taskdat[[formula.head]])
   }
-  lvls = length(unique(taskdat[[formula_head]]))
-  if (length(lvls)>2)
+  lvls = length(unique(taskdat[[formula.head]]))
+  if (length(lvls) > 2)
     stop("Use neuralnet to do binary classification")
-  if (!all(taskdat[[formula_head]]== 0 | taskdat[[formula_head]] == 1)){
-    taskdat[[formula_head]] = taskdat[[formula_head]]-1
+  if (!all(taskdat[[formula.head]] == 0 | taskdat[[formula.head]] == 1)){
+    taskdat[[formula.head]] = taskdat[[formula.head]] - 1
   }
-  if (sum(stri_detect_regex(cf, '\\.')) > 0){
-    varnames = nms[nms!=formula_head]
-    formula_head = stri_paste('as.numeric(',formula_head,')~', sep = " ")
-    formula_expand = stri_paste(formula_head, 
-                                stri_paste(varnames, collapse = "+", sep = " "), 
+  if (sum(stri_detect_regex(cf, "\\.")) > 0){
+    varnames = nms[nms != formula.head]
+    formula.head = stri_paste("as.numeric(", formula.head, ")~", sep = " ")
+    formula.expand = stri_paste(formula.head,
+                                stri_paste(varnames, collapse = "+", sep = " "),
                                 sep = " ")
-    formula_expand = as.formula(formula_expand)
-    f = formula_expand
+    formula.expand = as.formula(formula.expand)
+    f = formula.expand
   }
-  
+
   neuralnet::neuralnet(f, data = taskdat, linear.output = FALSE, ...)
 }
 
 #' @export
 predictLearner.classif.neuralnet = function(.learner, .model, .newdata, ...) {
   type = switch(.learner$predict.type, response = "class", prob = "raw")
-  
+
   p = neuralnet::compute(x = .model$learner.model, covariate = .newdata, ...)
   p = p[[2]]
-  
-  p = cbind(1-p, p)
+
+  p = cbind(1 - p, p)
   colnames(p) = .model$factor.levels[[1]]
-  
+
   if (type == "class") {
-    classes <- colnames(p)[max.col(p)]
+    classes = colnames(p)[max.col(p)]
     return(as.factor(classes))
     # p = factor(as.numeric(p>0.5), labels = .model$factor.levels$Class)
   }
