@@ -11,7 +11,8 @@ makeRLearner.classif.plr = function() {
     properties = c("twoclass", "numerics", "factors", "prob", "weights"),
     name = "Logistic Regression with a L2 Penalty",
     short.name = "plr",
-    note = "AIC and BIC penalty types can be selected via the new parameter `cp.type`."
+    note = "AIC and BIC penalty types can be selected via the new parameter `cp.type`.",
+    callees = "plr"
   )
 }
 
