@@ -12,7 +12,8 @@ makeRLearner.classif.probit = function() {
     properties = c("twoclass", "numerics", "factors", "prob", "weights"),
     name = "Probit Regression",
     short.name = "probit",
-    note = "Delegates to `glm` with `family = binomial(link = 'probit')`. We set 'model' to FALSE by default to save memory."
+    note = "Delegates to `glm` with `family = binomial(link = 'probit')`. We set 'model' to FALSE by default to save memory.",
+    callees = "glm"
   )
 }
 
