@@ -13,7 +13,8 @@ makeRLearner.classif.rFerns = function() {
     ),
     properties = c("numerics", "twoclass", "multiclass", "factors", "ordered", "oobpreds"),
     name = "Random ferns",
-    short.name = "rFerns"
+    short.name = "rFerns",
+    callees = "rFerns"
   )
 }
 
@@ -30,5 +31,5 @@ predictLearner.classif.rFerns = function(.learner, .model, .newdata, ...) {
 
 #' @export
 getOOBPredsLearner.classif.rFerns = function(.learner, .model) {
-  .model$learner.model$oobPreds
+  getLearnerModel(.model, more.unwrap = TRUE)$oobPreds
 }
