@@ -5,24 +5,25 @@ makeRLearner.classif.svm = function() {
     package = "e1071",
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "type", default = "C-classification", values = c("C-classification", "nu-classification")),
-      makeNumericLearnerParam(id = "cost",  default = 1, lower = 0, requires = quote(type=="C-classification")),
-      makeNumericLearnerParam(id = "nu", default = 0.5, requires = quote(type=="nu-classification")),
+      makeNumericLearnerParam(id = "cost",  default = 1, lower = 0, requires = quote(type == "C-classification")),
+      makeNumericLearnerParam(id = "nu", default = 0.5, requires = quote(type == "nu-classification")),
       makeNumericVectorLearnerParam("class.weights", len = NA_integer_, lower = 0),
       makeDiscreteLearnerParam(id = "kernel", default = "radial", values = c("linear", "polynomial", "radial", "sigmoid")),
-      makeIntegerLearnerParam(id = "degree", default = 3L, lower = 1L, requires = quote(kernel=="polynomial")),
-      makeNumericLearnerParam(id = "coef0", default = 0, requires = quote(kernel=="polynomial" || kernel=="sigmoid")),
-      makeNumericLearnerParam(id = "gamma", lower = 0, requires = quote(kernel!="linear")),
+      makeIntegerLearnerParam(id = "degree", default = 3L, lower = 1L, requires = quote(kernel == "polynomial")),
+      makeNumericLearnerParam(id = "coef0", default = 0, requires = quote(kernel == "polynomial" || kernel == "sigmoid")),
+      makeNumericLearnerParam(id = "gamma", lower = 0, requires = quote(kernel != "linear")),
       makeNumericLearnerParam(id = "cachesize", default = 40L),
       makeNumericLearnerParam(id = "tolerance", default = 0.001, lower = 0),
       makeLogicalLearnerParam(id = "shrinking", default = TRUE),
       makeIntegerLearnerParam(id = "cross", default = 0L, lower = 0L, tunable = FALSE),
       makeLogicalLearnerParam(id = "fitted", default = TRUE, tunable = FALSE),
-      makeLogicalVectorLearnerParam(id = "scale", default = c(TRUE), tunable = TRUE)
+      makeLogicalVectorLearnerParam(id = "scale", default = TRUE, tunable = TRUE)
     ),
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "class.weights"),
     class.weights.param = "class.weights",
     name = "Support Vector Machines (libsvm)",
-    short.name = "svm"
+    short.name = "svm",
+    callees = "svm"
   )
 }
 
