@@ -2,7 +2,7 @@
 makeRLearner.regr.mob = function() {
   makeRLearnerRegr(
     cl = "regr.mob",
-    package = "party",
+    package = c("party", "modeltools"),
     par.set = makeParamSet(
       makeNumericLearnerParam(id = "alpha", default = 0.05, lower = 0, upper = 1),
       makeLogicalLearnerParam(id = "bonferroni", default = TRUE),
@@ -19,7 +19,7 @@ makeRLearner.regr.mob = function() {
     properties = c("numerics", "factors", "weights"),
     name = "Model-based Recursive Partitioning  Yielding a Tree with Fitted Models Associated with each Terminal Node",
     short.name = "mob",
-    note = ""
+    callees = c("mob", "mob_control", "glinearModel", "linearModel")
   )
 }
 
@@ -38,7 +38,7 @@ trainLearner.regr.mob = function(.learner, .task, .subset, .weights = NULL, alph
     term.feats = feats
 
   target = getTaskTargetNames(.task)
-  f = as.formula(paste(target, "~", collapse(term.feats, sep = " + "), "|", collapse(part.feats, sep = " + ")))
+  f = as.formula(stri_paste(target, "~", collapse(term.feats, sep = " + "), "|", collapse(part.feats, sep = " + "), sep = " "))
 
   if (is.null(.weights)) {
     model = party::mob(f, data = getTaskData(.task, .subset), control = cntrl, ...)
