@@ -28,7 +28,7 @@ getLearnerTable = function() {
   return(tab)
 }
 
-filterLearnerTable = function(tab = getLearnerTable(), types = character(0L), properties = character(0L), check.packages = TRUE) {
+filterLearnerTable = function(tab = getLearnerTable(), types = character(0L), properties = character(0L), check.packages = FALSE) {
   contains = function(lhs, rhs) all(lhs %in% rhs)
 
   if (check.packages)
@@ -56,34 +56,34 @@ filterLearnerTable = function(tab = getLearnerTable(), types = character(0L), pr
 #' This will be a lot faster.
 #'
 #' Note that for general cost-sensitive learning, mlr currently supports mainly
-#' \dQuote{wrapper} approaches like \code{\link{CostSensWeightedPairsWrapper}},
+#' \dQuote{wrapper} approaches like [CostSensWeightedPairsWrapper],
 #' which are not listed, as they are not basic R learning algorithms.
-#' The same applies for many multilabel methods, see, e.g., \code{\link{makeMultilabelBinaryRelevanceWrapper}}.
+#' The same applies for many multilabel methods, see, e.g., [makeMultilabelBinaryRelevanceWrapper].
 #'
 #' @template arg_task_or_type
-#' @param properties [\code{character}]\cr
-#'   Set of required properties to filter for. Default is \code{character(0)}.
-#' @param quiet [\code{logical(1)}]\cr
+#' @param properties ([character])\cr
+#'   Set of required properties to filter for. Default is `character(0)`.
+#' @param quiet (`logical(1)`)\cr
 #'   Construct learners quietly to check their properties, shows no package startup messages.
 #'   Turn off if you suspect errors.
-#'   Default is \code{TRUE}.
-#' @param warn.missing.packages [\code{logical(1)}]\cr
+#'   Default is `TRUE`.
+#' @param warn.missing.packages (`logical(1)`)\cr
 #'   If some learner cannot be constructed because its package is missing,
 #'   should a warning be shown?
-#'   Default is \code{TRUE}.
-#' @param check.packages [\code{logical(1)}]\cr
-#'   Check if required packages are installed. Calls \code{find.package()}. 
-#'   If \code{create} is \code{TRUE}, this is done implicitly and the value of this parameter is ignored.
-#'   If \code{create} is \code{FALSE} and \code{check.packages} is \code{TRUE} the returned table only 
+#'   Default is `TRUE`.
+#' @param check.packages (`logical(1)`)\cr
+#'   Check if required packages are installed. Calls `find.package()`.
+#'   If `create` is `TRUE`, this is done implicitly and the value of this parameter is ignored.
+#'   If `create` is `FALSE` and `check.packages` is `TRUE` the returned table only
 #'   contains learners whose dependencies are installed.
-#'   If \code{check.packages} set to \code{FALSE}, learners that cannot actually be constructed because 
+#'   If `check.packages` set to `FALSE`, learners that cannot actually be constructed because
 #'   of missing packages may be returned.
-#'   Default is \code{FALSE}.
-#' @param create [\code{logical(1)}]\cr
+#'   Default is `FALSE`.
+#' @param create (`logical(1)`)\cr
 #'   Instantiate objects (or return info table)?
-#'   Packages are loaded if and only if this option is \code{TRUE}.
-#'   Default is \code{FALSE}.
-#' @return [\code{data.frame} | \code{list} of \code{\link{Learner}}].
+#'   Packages are loaded if and only if this option is `TRUE`.
+#'   Default is `FALSE`.
+#' @return ([data.frame` | `list` of [Learner]).
 #'   Either a descriptive data.frame that allows access to all properties of the learners
 #'   or a list of created learner objects (named by ids of listed learners).
 #' @examples
@@ -109,14 +109,14 @@ listLearners  = function(obj = NA_character_, properties = character(0L),
 #' @export
 #' @rdname listLearners
 listLearners.default  = function(obj = NA_character_, properties = character(0L),
-  quiet = TRUE, warn.missing.packages = TRUE, check.packages = TRUE, create = FALSE) {
+  quiet = TRUE, warn.missing.packages = TRUE, check.packages = FALSE, create = FALSE) {
 
   listLearners.character(obj = NA_character_, properties, quiet, warn.missing.packages, check.packages, create)
 }
 
 #' @export
 #' @rdname listLearners
-listLearners.character  = function(obj = NA_character_, properties = character(0L), quiet = TRUE, warn.missing.packages = TRUE, check.packages = TRUE, create = FALSE) {
+listLearners.character  = function(obj = NA_character_, properties = character(0L), quiet = TRUE, warn.missing.packages = TRUE, check.packages = FALSE, create = FALSE) {
   if (!isScalarNA(obj))
     assertSubset(obj, listTaskTypes())
   tab = getLearnerTable()
