@@ -12,5 +12,5 @@ selectFeaturesExhaustive = function(learner, task, resampling, measures, bit.nam
   }
   evalOptimizationStatesFeatSel(learner, task, resampling, measures, bits.to.features, control,
     opt.path, show.info, states, 1L, as.integer(NA))
-  makeFeatSelResultFromOptPath(learner, measures, control, opt.path)
+  makeFeatSelResultFromOptPath(learner, measures, resampling, control, opt.path, task = task, bits.to.features = bits.to.features)
 }
