@@ -6,7 +6,7 @@ tuneMultiCritGrid = function(learner, task, resampling, measures, par.set, contr
   xs = dfRowsToList(des, par.set)
   evalOptimizationStatesTune(learner, task, resampling, measures, par.set, control, opt.path,
     show.info, xs, dobs = seq_along(xs), eols = NA_integer_, remove.nas = TRUE, resample.fun = resample.fun)
-  makeTuneMultiCritResultFromOptPath(learner, par.set, measures, control, opt.path)
+  makeTuneMultiCritResultFromOptPath(learner, par.set, measures, resampling, control, opt.path)
 }
 
 
