@@ -3,27 +3,27 @@
 #' @description
 #' Optimizes the threshold of predictions based on probabilities.
 #' Works for classification and multilabel tasks.
-#' Uses \code{\link[BBmisc]{optimizeSubInts}} for normal binary class problems and \code{\link[cmaes]{cma_es}}
-#' for multiclass and multilabel problems.
+#' Uses [BBmisc::optimizeSubInts] for normal binary class problems and
+#' [GenSA::GenSA] for multiclass and multilabel problems.
 #'
 #' @template arg_pred
-#' @param measure [\code{\link{Measure}}]\cr
+#' @param measure ([Measure])\cr
 #'   Performance measure to optimize.
 #'   Default is the default measure for the task.
-#' @param task [\code{\link{Task}}]\cr
+#' @param task ([Task])\cr
 #'   Learning task. Rarely neeeded,
 #'   only when required for the performance measure.
-#' @param model [\code{\link{WrappedModel}}]\cr
+#' @param model ([WrappedModel])\cr
 #'   Fitted model. Rarely neeeded,
 #'   only when required for the performance measure.
-#' @param nsub [\code{integer(1)}]\cr
-#'   Passed to \code{\link[BBmisc]{optimizeSubInts}} for 2class problems.
+#' @param nsub (`integer(1)`)\cr
+#'   Passed to [BBmisc::optimizeSubInts] for 2class problems.
 #'   Default is 20.
-#' @param control [\code{list}]\cr
-#'   Control object for \code{\link[cmaes]{cma_es}} when used.
+#' @param control ([list])\cr
+#'   Control object for [GenSA::GenSA] when used.
 #'   Default is empty list.
-#' @return [\code{list}]. A named list with with the following components:
-#'   \code{th} is the optimal threshold, \code{perf} the performance value.
+#' @return ([list]). A named list with with the following components:
+#'   `th` is the optimal threshold, `perf` the performance value.
 #' @family tune
 #' @export
 tuneThreshold = function(pred, measure, task, model, nsub = 20L, control = list()) {
@@ -49,17 +49,21 @@ tuneThreshold = function(pred, measure, task, model, nsub = 20L, control = list(
   fitn = function(x) {
     if (ttype == "multilabel" || k > 2)
       names(x) = cls
-    performance(setThreshold(pred, x), measure, task, model)
+    performance(setThreshold(pred, x), measure, task, model, simpleaggr = TRUE)
   }
 
   if (ttype == "multilabel" || k > 2L) {
-    requirePackages("cmaes", why = "tuneThreshold", default.method = "load")
-    start = rep(0.5, k)
-    or = cmaes::cma_es(par = start, fn = fitn, lower = 0, upper = 1, control = control)
+    requirePackages("GenSA", why = "tuneThreshold", default.method = "load")
+    start = rep(1 / k, k)
+
+    ctrl = list(smooth = FALSE, simple.function = TRUE, max.call = 3000L, temperature = 250,
+      visiting.param = 2.5, acceptance.param = -15)
+    or = GenSA::GenSA(par = start, fn = fitn, lower = rep(0, k),
+      upper = rep(1, k), control = ctrl)
     th = or$par / sum(or$par)
     names(th) = cls
-    perf = or$val
-  } else { # classif with k = 2
+    perf = or$value
+  } else {# classif with k = 2
     or = optimizeSubInts(f = fitn, lower = 0, upper = 1, maximum = !measure$minimize, nsub = nsub)
     th = or[[1]]
     perf = or$objective
