@@ -1,11 +1,11 @@
 context("convertMLBenchObjToTask")
 
 test_that("convertMLbenchObjToTask", {
-  library(mlbench)
+  requirePackages("!mlbench")
   # get all mlbench.* functions, 1spiral does not work
   fs = ls("package:mlbench", pattern = "mlbench")
   n = 77L
-  for (f in setdiff(fs, c("mlbench.1spiral"))) {
+  for (f in setdiff(fs, "mlbench.1spiral")) {
     task = convertMLBenchObjToTask(f, n = n)
     expect_is(task, "Task")
     # for some, n is not properly respected in mlbench
@@ -22,5 +22,3 @@ test_that("convertMLbenchObjToTask", {
     expect_equal(getTaskId(task), d)
   }
 })
-
-
