@@ -3,7 +3,7 @@ context("getOOBPreds")
 test_that("getOOBPreds", {
   lrns = list(
     makeLearner("classif.randomForest"),
-    makeFilterWrapper(learner = "classif.randomForest", fw.method = "information.gain",
+    makeFilterWrapper(learner = "classif.randomForest", fw.method = "FSelectorRcpp_information.gain",
       fw.abs = 2))
 
   task = subsetTask(binaryclass.task, subset = c(10:20, 180:190),
