@@ -13,9 +13,9 @@ test_that("test_CritDifferences", {
   res$results$binary$classif.nnet$aggr[2] = 1
   res$results$multiclass$classif.nnet$aggr[2] = 1
 
-  expect_warning(r1 <- generateCritDifferencesData(res))
+  expect_warning({r1 = generateCritDifferencesData(res)})
   expect_is(r1, "CritDifferencesData")
-  expect_warning(r2 <- generateCritDifferencesData(res, ber, test = "nemenyi"))
+  expect_warning({r2 = generateCritDifferencesData(res, ber, test = "nemenyi")})
   expect_is(r2, "CritDifferencesData")
   r3 = generateCritDifferencesData(res, ber, p.value = 0.5, test = "bd")
   expect_is(r3, "CritDifferencesData")
@@ -24,7 +24,7 @@ test_that("test_CritDifferences", {
   lrns2 = list(makeLearner("classif.rpart", "rpart1"),
                makeLearner("classif.rpart", "rpart2"))
   res2 = benchmark(lrns2, tasks, rdesc, meas)
-  expect_warning(r4 <- generateCritDifferencesData(res2, acc, p.value = 0.3, test = "bd"),
+  expect_warning({r4 = generateCritDifferencesData(res2, acc, p.value = 0.3, test = "bd")},
                  "Learner performances might be exactly equal.")
   expect_is(r4, "CritDifferencesData")
 
