@@ -8,20 +8,20 @@ test_that("predict", {
   wl.lda = makeLearner("classif.lda", predict.type = "prob")
 
   cm2 = train(makeLearner("classif.lda"), multiclass.task, subset = inds)
-  cp2 = predict(cm2, newdata = data[inds,])
-  cp2b = predict(cm2, newdata = data[inds,-5])
+  cp2 = predict(cm2, newdata = data[inds, ])
+  cp2b = predict(cm2, newdata = data[inds, -5])
   requirePackagesOrSkip("MASS", default.method = "load")
-  ext2 = MASS::lda(formula, data = data[inds,])
-  pred2 = predict(ext2,newdata = data[inds,])$class
+  ext2 = MASS::lda(formula, data = data[inds, ])
+  pred2 = predict(ext2, newdata = data[inds, ])$class
 
   expect_equal(cp2$data$response, pred2)
   expect_equal(cp2b$data$response, pred2)
 
   cm3 = train(wl.lda, multiclass.task, subset = inds)
-  cp3 = predict(cm3, newdata = data[multiclass.test.inds,])
-  ext3 = MASS::lda(formula, data = data[inds,])
-  pred3 = predict(ext3,newdata = data[multiclass.test.inds,])$class
-  prob3 = predict(ext3,newdata = data[multiclass.test.inds,])$post
+  cp3 = predict(cm3, newdata = data[multiclass.test.inds, ])
+  ext3 = MASS::lda(formula, data = data[inds, ])
+  pred3 = predict(ext3, newdata = data[multiclass.test.inds, ])$class
+  prob3 = predict(ext3, newdata = data[multiclass.test.inds, ])$post
   expect_equal(cp3$data$response, pred3)
   expect_equal(prob3, as.matrix(getPredictionProbabilities(cp3, colnames(prob3))))
   expect_true(is.numeric(getPredictionProbabilities(cp3, "setosa")))
@@ -35,7 +35,7 @@ test_that("predict", {
 
   df3 = as.data.frame(cp3)
   df4 = as.data.frame(cp4)
-  expect_equal(df3, df4[,-1])
+  expect_equal(df3, df4[, -1])
 
   cm5 = train(wl.lda, binaryclass.task, subset = binaryclass.train.inds)
   cp5a = predict(cm5, task = binaryclass.task, subset = binaryclass.test.inds)
@@ -64,7 +64,7 @@ test_that("predict works with type = se", {
 
 test_that("predict works with strange class labels", {
   df = binaryclass.df
-  levels(df[,binaryclass.target]) = c(-1,1)
+  levels(df[, binaryclass.target]) = c(-1, 1)
   task = makeClassifTask(data = df, target = binaryclass.target)
   mod = train(makeLearner("classif.lda", predict.type = "prob"), task = task)
   p = predict(mod, task = task)
@@ -86,7 +86,7 @@ test_that("predict works with newdata / subset", {
 
 test_that("predict preserves rownames", {
   data = multiclass.df
-  rownames(data) = nrow(data):1
+  rownames(data) = rev(seq_len(nrow(data)))
   task = makeClassifTask(data = data, target = multiclass.target)
   # kknn (or its mlr intergration) seems to NOT preserve rownames, issue 142 was reported
   mod = train("classif.kknn", task = task)
@@ -143,4 +143,3 @@ test_that("predict works with data.table as newdata", {
   mod = train(lrn, iris.task)
   expect_warning(predict(mod, newdata = data.table(iris)), regexp = "Provided data for prediction is not a pure data.frame but from class data.table, hence it will be converted.")
 })
-
