@@ -32,3 +32,25 @@ test_that("resample getter work", {
   expect_equal(r2$measures.train$mmce, unname(vnapply(getRRPredictionList(r2)$train, performance, mmce)))
   expect_equal(r2$measures.test$mmce, unname(vnapply(getRRPredictionList(r2)$test, performance, mmce)))
 })
+
+test_that("getRRPredictionList with se predict.type", {
+  rinst = makeResampleInstance(hout, regr.task)
+  rinst$desc$predict = "both"
+
+  rr = resample(makeLearner("regr.lm", predict.type = "se"), regr.task, rinst)
+  pl = getRRPredictionList(rr)
+
+  tmod = train(makeLearner("regr.lm", predict.type = "se"),
+    regr.task, rinst$train.inds[[1]])
+
+  ptrain = predict(tmod, regr.task, subset = rinst$train.inds[[1]])
+  attr(ptrain$data, "row.names") = as.integer(row.names(ptrain$data))
+
+  ptest = predict(tmod, regr.task, subset = rinst$test.inds[[1]])
+  attr(ptest$data,  "row.names") = as.integer(row.names(ptest$data))
+
+  expect_equal(pl$train[[1]]$data, ptrain$data)
+
+  expect_equal(pl$test[[1]]$data, ptest$data)
+
+})
