@@ -35,6 +35,14 @@ test_that("selectFeatures", {
   expect_true(setequal(colnames(df), c("b1", "b2", "mmce.test.mean", "dob", "eol",
         "exec.time", "error.message")))
   expect_equal(nrow(df), 2L)
+
+  expect_error(selectFeatures(lrn, task = multiclass.task, resampling = rdesc, bit.names = bns, control = ctrl, show.info = FALSE), "you also have to set bits.to.features")
+
+  expect_error(selectFeatures(lrn, task = multiclass.task, resampling = rdesc, bit.names = bns, bits.to.features = function(x, task) binaryToFeatures(x, getTaskFeatureNames(task)), control = ctrl, show.info = FALSE), "Must have length")
+
+  expect_error(selectFeatures(lrn, task = multiclass.task, resampling = rdesc, bits.to.features = function(x, task) c("test1", "test2"), control = ctrl, show.info = FALSE), "\\(test1,test2\\) that are not in the task.")
+
+  expect_error(selectFeatures(lrn, task = multiclass.task, resampling = rdesc, bits.to.features = function(x, task) NULL, control = ctrl, show.info = FALSE), "but an object of type NULL")
 })
 
 test_that("threshold tuning with feature selection", {
@@ -59,11 +67,12 @@ test_that("show info works in selectFeatures", {
 })
 
 # we had a bug here when an empty model was created and isFailureModel could not be called on it, cf. #284
-test_that("selectFeatures/sfs works with wrapper" , {
+test_that("selectFeatures/sfs works with wrapper", {
   ctrl = makeFeatSelControlSequential(method = "sfs")
   lrn1 = makeLearner("classif.LiblineaRL2LogReg")
   lrn2 = makeWeightedClassesWrapper(lrn1, wcw.param = "wi")
   task = subsetTask(binaryclass.task, features = getTaskFeatureNames(binaryclass.task)[1:2])
   rdesc = makeResampleDesc("Holdout", split = 0.8, stratify = TRUE)
   sel = selectFeatures(lrn2, task, rdesc, control = ctrl)
+  expect_class(sel, "FeatSelResult")
 })
