@@ -17,15 +17,15 @@ test_that("classif_cforest", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(binaryclass.formula, data = binaryclass.train)
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
     m = do.call(party::cforest, pars)
     old.predicts.list[[i]] = predict(m, newdata = binaryclass.test)
-    p = predict(m, newdata = binaryclass.test, type = 'prob')
-    old.probs.list[[i]] = sapply(p, '[', 1)
+    p = predict(m, newdata = binaryclass.test, type = "prob")
+    old.probs.list[[i]] = sapply(p, "[", 1)
   }
 
   testSimpleParsets("classif.cforest", binaryclass.df, binaryclass.target, binaryclass.train.inds,
