@@ -38,3 +38,19 @@ test_that("class names are integers and probabilities predicted (#1787)", {
   r = resample(gb.lrn, classif.task, rin)
   expect_false(is.null(r$pred))
 })
+
+test_that("feature importances are returned", {
+  iris2 = iris[iris$Species %in% c("versicolor", "virginica"), ]
+  iris2$Species = droplevels(iris2$Species)
+  task = makeClassifTask(data = iris2, target = "Species")
+
+  lrn = makeLearner("classif.h2o.glm")
+  mod = train(lrn, task)
+  feat.imp = getFeatureImportance(mod)$res
+  feat.imp.h2o = na.omit(h2o::h2o.varimp(getLearnerModel(mod))[, c("names", "coefficients")])
+  # Convert to data.frame with same structure for equality check
+  feat.imp.h2o = data.frame(as.list(xtabs(coefficients ~ names, data = feat.imp.h2o)))[names(feat.imp)]
+
+  expect_equal(feat.imp,
+               feat.imp.h2o)
+})
