@@ -7,10 +7,10 @@ test_that("regr_RRF", {
     list(ntree = 5, mtry = 2),
     list(ntree = 5, mtry = 4)
   )
-  
+
   old.predicts.list = list()
-  
-  for (i in 1:length(parset.list)) {
+
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(formula = regr.formula, data = regr.train)
     pars = c(pars, parset)
@@ -20,7 +20,7 @@ test_that("regr_RRF", {
     p = predict(m, newdata = regr.test, type = "response")
     old.predicts.list[[i]] = p
   }
-  
+
   testSimpleParsets("regr.RRF", regr.df, regr.target,
                     regr.train.inds, old.predicts.list, parset.list)
 })
