@@ -5,6 +5,7 @@ test_that("tuneGrid", {
   reso = 3L
   c.seq = 2^seq(-2, 2, length.out = reso)
   sigma.seq = 2^seq(-2, 2, length.out = reso)
+  sigma.seq.2 = 2^seq(-2, 2, length.out = reso * 2)
   rin = makeFixedHoldoutInstance(train.inds = seq(1, 150, 2), test.inds = seq(2, 150, 2), size = 150)
   # discretized param set
   ps1 = makeParamSet(
@@ -13,10 +14,21 @@ test_that("tuneGrid", {
   )
   ctrl = makeTuneControlGrid()
   tr1 = tuneParams(lrn, multiclass.task, rin, par.set = ps1, control = ctrl)
+  expect_number(tr1$y, lower = 0, upper = 0.2)
   op1 = as.data.frame(tr1$opt.path)
   op1$C = as.numeric(as.character(op1$C))
   op1$sigma = as.numeric(as.character(op1$sigma))
 
+  ps1.2 = makeParamSet(
+    makeDiscreteParam("C", values = c.seq),
+    makeDiscreteParam("sigma", values = sigma.seq.2)
+  )
+  tr1.2 = tuneParams(lrn, multiclass.task, rin, par.set = ps1.2, control = ctrl, measures = acc)
+  expect_number(tr1.2$y, lower = 0.8, upper = 1)
+  op1.2 = as.data.frame(tr1.2$opt.path)
+  op1.2$C = as.numeric(as.character(op1.2$C))
+  op1.2$sigma = as.numeric(as.character(op1.2$sigma))
+
   # normal param set
   ps2 = makeParamSet(
     makeNumericParam("C", -2, 2, trafo = function(x) 2^x),
@@ -28,6 +40,12 @@ test_that("tuneGrid", {
   op1$exec.time = op2$exec.time = NULL
   expect_equal(sortByCol(op1, c("C", "sigma")), sortByCol(op2, c("C", "sigma")))
 
+  ctrl = makeTuneControlGrid(resolution = c(C = reso, sigma = reso * 2))
+  tr2.2 = tuneParams(lrn, multiclass.task, rin, par.set = ps2, control = ctrl, measures = acc)
+  op2.2 = as.data.frame(trafoOptPath(tr2.2$opt.path))
+  op1.2$exec.time = op2.2$exec.time = NULL
+  expect_equal(sortByCol(op1.2, c("C", "sigma")), sortByCol(op2.2, c("C", "sigma")))
+
 })
 
 test_that("tuneGrid works with dependent params", {
